"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const native_1 = require("../../native");
const child_process_1 = require("../../utils/child-process");
const package_manager_1 = require("../../utils/package-manager");
const child_process_2 = require("child_process");
async function default_1(options, context) {
    const pm = (0, package_manager_1.getPackageManagerCommand)();
    try {
        let command = pm.run(options.script, options.__unparsed__.join(' '));
        let cwd = path.join(context.root, context.projectsConfigurations.projects[context.projectName].root);
        let env = process.env;
        if (process.stdout.isTTY) {
            await ptyProcess(command, cwd, env);
        }
        else {
            nodeProcess(command, cwd, env);
        }
        return { success: true };
    }
    catch (e) {
        return { success: false };
    }
}
exports.default = default_1;
function nodeProcess(command, cwd, env) {
    (0, child_process_2.execSync)(command, {
        stdio: ['inherit', 'inherit', 'inherit'],
        cwd,
        env,
    });
}
async function ptyProcess(command, cwd, env) {
    return new Promise((res, rej) => {
        const cp = new child_process_1.PseudoTtyProcess((0, native_1.runCommand)(command, cwd, env));
        cp.onExit((code) => {
            if (code === 0) {
                res();
            }
            else if (code >= 128) {
                process.exit(code);
            }
            else {
                rej();
            }
        });
    });
}
